import javax.swing.JOptionPane;
import javax.swing.JDialog;
import javax.swing.JTextField;
import java.beans.*; //property change stuff
import java.awt.*;
import java.awt.event.*;

/* From CustomDialog.java from 1.4 example used by DialogDemo.java. */
class DensityDialog extends JDialog
                   implements ActionListener,
                              PropertyChangeListener {


    private double m_MinDensity;
    private double m_MaxDensity;

    private JTextField m_MinDensityText;
    private JTextField m_MaxDensityText;

    private Minesweep m_Parent;

    private JOptionPane optionPane;

    private String btnString1 = "OK";
    private String btnString2 = "Cancel";

    public double getMinDensity() {
        return m_MinDensity;
    }

    public double getMaxDensity() {
        return m_MaxDensity;
    }

    /** Creates the reusable dialog. */
    public DensityDialog(Frame aFrame, String aWord, Minesweep parent,
			 double minDensity, double maxDensity) {
        super(aFrame, true);
        m_Parent = parent;

	m_MinDensity = minDensity;
	m_MaxDensity = maxDensity;

        setTitle("Density setting");
        m_MinDensityText = new JTextField("" + m_MinDensity);
        m_MaxDensityText = new JTextField("" + m_MaxDensity);

        //Create an array of the text and components to be displayed.
        String msgString1 = "Minimum mine density";
        String msgString2 = "Maximum mine density";
        Object[] array = {msgString1, m_MinDensityText, msgString2, m_MaxDensityText};

        //Create an array specifying the number of dialog buttons
        //and their text.
        Object[] options = {btnString1, btnString2};

        //Create the JOptionPane.
        optionPane = new JOptionPane(array,
                                    JOptionPane.QUESTION_MESSAGE,
                                    JOptionPane.YES_NO_OPTION,
                                    null,
                                    options,
                                    options[0]);

        //Make this dialog display it.
        setContentPane(optionPane);

        //Handle window closing correctly.
        setDefaultCloseOperation(DO_NOTHING_ON_CLOSE);
        addWindowListener(new WindowAdapter() {
                public void windowClosing(WindowEvent we) {
                /*
                 * Instead of directly closing the window,
                 * we're going to change the JOptionPane's
                 * value property.
                 */
                    optionPane.setValue(new Integer(
                                        JOptionPane.CLOSED_OPTION));
            }
        });

        //Ensure the text field always gets the first focus.
        addComponentListener(new ComponentAdapter() {
            public void componentShown(ComponentEvent ce) {
                m_MinDensityText.requestFocusInWindow();
            }
        });

        //Register an event handler that puts the text into the option pane.
        m_MinDensityText.addActionListener(this);
        m_MaxDensityText.addActionListener(this);

        //Register an event handler that reacts to option pane state changes.
        optionPane.addPropertyChangeListener(this);
    }

    /** This method handles events for the text field. */
    public void actionPerformed(ActionEvent e) {
        optionPane.setValue(btnString1);
    }

    /** This method reacts to state changes in the option pane. */
    public void propertyChange(PropertyChangeEvent e) {
        String prop = e.getPropertyName();

        if (isVisible()
         && (e.getSource() == optionPane)
         && (JOptionPane.VALUE_PROPERTY.equals(prop) ||
             JOptionPane.INPUT_VALUE_PROPERTY.equals(prop))) {
            Object value = optionPane.getValue();

            if (value == JOptionPane.UNINITIALIZED_VALUE) {
                //ignore reset
                return;
            }

            //Reset the JOptionPane's value.
            //If you don't do this, then if the user
            //presses the same button next time, no
            //property change event will be fired.
            optionPane.setValue(JOptionPane.UNINITIALIZED_VALUE);

            if (btnString1.equals(value)) {

		double tmp;
		boolean ok = true;

		// Min value
		try {
		    tmp = Double.parseDouble(m_MinDensityText.getText());
		    if (tmp < 0) ok = false;
		    m_MinDensity = tmp;
		} catch(Exception ee) {
		    ok = false;
		}
		if (!ok) {
		    m_MinDensityText.selectAll();
		    JOptionPane.showMessageDialog(
						  DensityDialog.this,
						  "Min  value is invalid. ",
						  "Try again",
						  JOptionPane.ERROR_MESSAGE);
		    m_MinDensityText.requestFocusInWindow();
		    return;
		}

		// Get max value
		try {
		    tmp = Double.parseDouble(m_MaxDensityText.getText());
		    if (tmp < 0) ok = false;
		    m_MaxDensity = tmp;
		} catch(Exception ee) {
		    ok = false;
		}
		if (!ok) {
		    m_MaxDensityText.selectAll();
		    JOptionPane.showMessageDialog(
						  DensityDialog.this,
						  "Max value is invalid. ",
						  "Try again",
						  JOptionPane.ERROR_MESSAGE);
		    m_MaxDensityText.requestFocusInWindow();
		    return;
		}


		System.out.println("OK input");
		clearAndHide();

            } else { //user closed dialog or clicked cancel
		m_MinDensity = -1;
                clearAndHide();
            }
        }
    }

    /** This method clears the dialog and hides it. */
    public void clearAndHide() {
        m_MinDensityText.setText(null);
        m_MaxDensityText.setText(null);
        setVisible(false);
    }
}
